@@ -80,7 +80,11 @@ static KonqMainWindow* handleCommandLine(QCommandLineParser &parser, const QStri
         }
 
         KonqSessionManager::self()->restoreSessions(sessionPath);
-        return nullptr;
+        if (!KonqMainWindow::mainWindowList()->isEmpty()) {
+            return KonqMainWindow::mainWindowList()->first();
+        } else {
+            return nullptr;
+        }
     }
 
     // Ask the user to recover session if applicable
