@@ -45,7 +45,7 @@
 #include <kacceleratormanager.h>
 #include <konqpixmapprovider.h>
 #include <kstandardshortcut.h>
-#include <ktabbar.h>
+#include "ktabbar.h"
 
 //###################################################################
 
@@ -196,9 +196,7 @@ void KonqFrameTabs::setTabIcon(const QUrl &url, QWidget *sender)
     //qCDebug(KONQUEROR_LOG) << "KonqFrameTabs::setTabIcon( " << url << " , " << sender << " )";
     QIcon iconSet = QIcon::fromTheme(KonqPixmapProvider::self()->iconNameFor(url));
     const int pos = indexOf(sender);
-    if (tabIcon(pos).pixmap(iconSize()).serialNumber() != iconSet.pixmap(iconSize()).serialNumber()) {
-        KTabWidget::setTabIcon(pos, iconSet);
-    }
+    KTabWidget::setTabIcon(pos, iconSet);
 }
 
 void KonqFrameTabs::activateChild()
@@ -432,10 +430,9 @@ void KonqFrameTabs::slotInitiateDrag(QWidget *w)
         QMimeData *md = new QMimeData;
         md->setUrls(QList<QUrl>() << frame->activeChildView()->url());
         d->setMimeData(md);
-        QString iconName = KMimeType::iconNameForUrl(frame->activeChildView()->url());
+        QString iconName = KIO::iconNameForUrl(frame->activeChildView()->url());
         d->setPixmap(KIconLoader::global()->loadIcon(iconName, KIconLoader::Small, 0));
-        //d->setPixmap( KIconLoader::global()->loadMimeTypeIcon(KMimeType::pixmapForURL( frame->activeChildView()->url(), 0), KIconLoader::Small ) );
-        d->start();
+        d->exec();
     }
 }
 
@@ -529,7 +526,7 @@ bool KonqFrameTabs::accept(KonqFrameVisitor *visitor)
 void KonqFrameTabs::slotCurrentChanged(int index)
 {
     const KColorScheme colorScheme(QPalette::Active, KColorScheme::Window);
-    setTabTextColor(index, colorScheme.foreground(KColorScheme::NormalText).color());
+    tabBar()->setTabTextColor(index, colorScheme.foreground(KColorScheme::NormalText).color());
 
     KonqFrameBase *currentFrame = tabAt(index);
     if (currentFrame && !m_pViewManager->isLoadingProfile()) {
@@ -587,7 +584,7 @@ void KonqFrameTabs::setLoading(KonqFrameBase *frame, bool loading)
             color = colorScheme.foreground(KColorScheme::NormalText).color();
         }
     }
-    setTabTextColor(pos, color);
+    tabBar()->setTabTextColor(pos, color);
 }
 
 void KonqFrameTabs::replaceChildFrame(KonqFrameBase *oldFrame, KonqFrameBase *newFrame)
